@@ -1,26 +1,27 @@
 est_multilogit <-
 function(Y,Xdis,label=1:n,be=NULL,Pdis=NULL,dis=FALSE,fort=TRUE,ex=FALSE){
-		
+
 # fit multinomial logit model for reponses included in Y
 # covariates in matrix X (two formats are allows for X: with binary responses it is n x ncov, with more response categories it is ncat x ncov x ndis)
-# label, in case of redundacies are the labels say to which design matrix in Xdis each row of Y is referred		
-# ex = TRUE if exit after only computing score and information		
-		
-time = proc.time()
+# label, in case of redundacies are the labels say to which design matrix in Xdis each row of Y is referred
+# ex = TRUE if exit after only computing score and information
+
+#time = proc.time()
+
 # preliminaries
      n = dim(Y)[1]
  	 k = dim(Y)[2]
      nbe = dim(Xdis)[2]
      ndis = max(label)
-    
+
 # correct covariance matrix
-     if(length(dim(Xdis))==2) Xdis = aperm(array(Xdis,c(ndis,nbe,1),c(3,2,1)))    
+     if(length(dim(Xdis))==2) Xdis = aperm(array(Xdis,c(ndis,nbe,1),c(3,2,1)))
      if(dim(Xdis)[1]<k){
      	Xdis0 = Xdis
      	Xdis = array(0,c(k,nbe,ndis))
      	Xdis[2:k,,] = Xdis0
-     } 
-    
+     }
+
 #print(c(4,proc.time()-time))
 # starting values
 
@@ -30,8 +31,8 @@ time = proc.time()
 	if(is.null(Pdis)){
 		Pdis = prob_multilogit(Xdis,be,label,fort)$Pdis
 	}
-		
-    Ydis = matrix(0,ndis,k)	
+
+    Ydis = matrix(0,ndis,k)
 	if(fort==F){
 	    for(i in 1:ndis){
 		    li = (label==i)
@@ -39,7 +40,7 @@ time = proc.time()
 	    }
 	}else{
         out = .Fortran("sum_Y",Ydis=Ydis,Y=Y,label=as.integer(label),ndis=as.integer(ndis),ns=as.integer(n),k=as.integer(k))
-        Ydis = out$Ydis	
+        Ydis = out$Ydis
     }
     ny = rowSums(Ydis)
     lk = sum(Ydis*log(Pdis))
@@ -47,16 +48,16 @@ time = proc.time()
 # iterate until convergence
     it = 0; lko = lk
     while((lk-lko>10^-6 & it<100) | it==0){
-        it = it+1; lko = lk 
+        it = it+1; lko = lk
     	if(fort==F){
         	sc = 0; Fi = 0
-        
+
 	        for(i in 1:ndis){
 		        pdis = Pdis[i,]
 		        sc = sc+t(Xdis[,,i])%*%(Ydis[i,]-ny[i]*pdis)
 		        Fi = Fi+ny[i]*t(Xdis[,,i])%*%(diag(pdis)-pdis%o%pdis)%*%Xdis[,,i]
 	        }
-	       
+
 	    }else{
             out = .Fortran("nr_multilogit",Xdis=Xdis,be=be,Pdis=Pdis,Ydis=Ydis,ny=ny,k=as.integer(k),ndis=as.integer(ndis),ncov=as.integer(nbe),
             sc=rep(0,nbe),Fi=matrix(0,nbe,nbe))
@@ -71,17 +72,16 @@ time = proc.time()
 	        while(flag){
 	        	be = be0+dbe
 	        	Eta = matrix(0,ndis,k)
-	  #      	browser()
 	   		 for(i in 1:ndis){
-	        		if(nbe==1) Eta[i,] = Xdis[,,i]*be
+	        		if(nbe==1) Eta[i,] = Xdis[,,i]*c(be)
 	        		else Eta[i,] = Xdis[,,i]%*%be
-	        	}	
+	        	}
 	        	if(max(abs(Eta))>100){
 	        		dbe = dbe/2
-	        		flag = TRUE	
+	        		flag = TRUE
 	        	}else{
 	        		flag = FALSE
-	        	}	        	
+	        	}
 	        }
 	    }
 # compute again probabilities
